<TS language="zh" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>创建一个新地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新建</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制当前已选地址到系统剪切板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;复制</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关&amp;闭</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表中删除当前已选地址</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>输入要搜索的地址或标签</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>将当前选项卡中的数据导出到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;导出</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;删除</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>选择想要发送币的地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>选择接收币的地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>选&amp;择</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>发送地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>这些是你的比特币支付地址。在发送之前，一定要核对金额和接收地址。</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制 &amp;标记</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>导出地址列表</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔的文件 (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>试图将地址列表保存为%1时出错。请再试一次。</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>密码对话框</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>输入密码</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>新密码</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>重复新密码</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>显示密码</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>此操作需要您的钱包密码来解锁钱包</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>解锁钱包</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>此操作需要您的钱包密码来解密钱包。</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>解密钱包</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>修改密码</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>确认钱包密码</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>注意：如果你加密了钱包，丢失了密码，您将&lt;b&gt;丢失所有的比特币。</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>确定要加密您的钱包吗?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>输入钱包的新密码。&lt;br/&gt;密码中请使用&lt;b&gt;10个或更多随机字符&lt;/b&gt;，或&lt;b&gt;8个或更多的单词&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>输入钱包的旧密码和新密码。</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>记住，加密您的钱包并不能完全保护您的比特币不被您电脑中的恶意软件窃取。</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>钱包即将被加密编码。</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>你的钱包即将被加密编码。</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>你的钱包已被加密编码。</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>重要提示：您以前对钱包文件所做的任何备份都应该替换为新的加密钱包文件。出于安全原因，一旦您开始使用新的加密钱包，以前未加密钱包文件备份将变得无用。</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>钱包加密失败</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>由于内部错误，钱包加密失败。您的钱包没有加密。</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>提供的密码不匹配。</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>钱包解锁失败</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>输入的钱包密码不正确。</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>钱包解密失败</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>钱包密码更改成功。</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>注意：大写锁定键打开了!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/子网掩码</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>禁止到</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>签名 &amp;消息...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>与网络同步...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;概述</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>显示钱包的一般概述</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;交易</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>浏览交易历史</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退&amp;出</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>退出应用</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;关于 %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>显示关于%1的信息</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>显示关于 Qt 的信息</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;选项</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>配置选项%1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;加密钱包...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;备份钱包...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;修改密码...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>打开 &amp;URI...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>创建钱包</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>创建一个新的钱包</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>钱包：</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>禁用网络活动。</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>正在同步Headers (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>重新索引磁盘上的区块...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>启用代理:%1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>发送比特币到一个比特币地址</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>备份钱包到另一个位置</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>更改钱包密码</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;验证消息...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;发送</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;接受</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;显示 / 隐藏</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>显示或隐藏主窗口</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>加密您的钱包私钥</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>用您的比特币地址签名信息，以证明拥有它们</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>验证消息，确保它们是用指定的比特币地址签名的</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;文件</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>标签工具栏</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>请求支付(生成二维码和比特币链接)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>显示使用过的发送地址或标签的列表</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>显示使用接收的地址或标签的列表</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;命令行选项</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>索引磁盘上的区块...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>处理磁盘上的区块...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>已处理 %n 的历史交易区块</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 落后</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>上次接收到的块是在%1之前生成的。</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>之后的交易还不可见。</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>消息</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>最新的</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file...</source>
        <translation type="unfinished">从文件加载PSBT...</translation>
    </message>
    <message>
        <source>Load PSBT from clipboard...</source>
        <translation type="unfinished">从剪贴板加载PSBT...</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>结点窗口</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>打开结点的调试和诊断控制台</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation>&amp;发送地址</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation>&amp;接受地址</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation>打开比特币: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>打开钱包</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>打开一个钱包</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>关闭钱包...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>关闭钱包</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>显示%1帮助消息以获得可能包含Bitcoin命令行选项的列表</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation>无可用钱包</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;窗口</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>缩放</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation>主窗口</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 客户端</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform>%n 活跃的链接到比特币网络</numerusform><numerusform>%n 活跃的链接到比特币网络</numerusform></translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>连接到节点...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>跟进中</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>日期：%1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>总计：%1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation>钱包：%1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>类型：%1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>标签：%1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>地址：%1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>发送交易</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>入账交易</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>HD密钥生成 &lt;b&gt;被允许&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>HD密钥生成 &lt;b&gt;被禁止&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>私钥&lt;b&gt;被禁止&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>钱包是&lt;b&gt;加密的&lt;/b&gt;，目前&lt;b&gt;已解锁&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>钱包是&lt;b&gt;加密的&lt;/b&gt;，目前&lt;b&gt;已锁定&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>发生致命错误。%1 已经无法继续安全运行并即将退出。</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>币种选择</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>字节：</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>总计：</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手续费：</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>粉尘：</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>扣除费用后：</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>变化：</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(未)选择所有</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>树模式</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>列表模式</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>总计</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>收到，夹带标签</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>收到，夹带地址</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>确认数</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>复制金额</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;复制标签</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;复制金额</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;复制交易 ID</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;锁定未消费的</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;解锁未消费</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>复制数量</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>复制费用</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>复制扣除费用</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>复制字节</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>复制改变</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 锁住)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>如果任何接收方接收到的金额小于当前粉尘交易的阈值，则此标签将变为红色。</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>每个输入可以改变+/- %1 satoshi(s)。</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation>创建钱包</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation>创建钱包</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>钱包</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>钱包名称</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation>编码钱包。钱包将会根据你选择的密码进行加密编码。</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>加密钱包</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation>禁用这个钱包的私钥。禁用私钥的钱包将没有私钥，也不能使用HD种子或者导入的私钥。对于仅供查看的钱包这是理想的设置。</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation>禁用私钥</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation>创建一个空白钱包。空白钱包没有起始的私钥和脚本。稍后可以倒入私钥和地址、设置HD种子。</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation>创建空白钱包</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>编辑地址</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;标签</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>与此地址列表关联的标签</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>与此地址列表项关联的地址。只能修改为发送地址。</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;地址</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>新的发送地址</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>编辑接收地址</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>编辑发送地址</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>输入的地址"%1"不是有效的比特币地址。</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation>地址“%1”作为标签为“%2”的接收地址已存在，无法新增为发送地址。</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation>输入的地址“%1”在标签为“%2”的地址簿中已存在</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>不能解锁钱包</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>新的密钥生成失败</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>新的数据目录将创建</translation>
    </message>
    <message>
        <source>name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>目录已存在。如果你打算在此创建新目录，添加 %1。</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>路径已存在，并非目录。</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>无法在此创建数据目录。</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>关于 %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>命令行选项</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>欢迎</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>欢迎到 %1。</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>使用默认的数据目录</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>使用自定数据目录</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>比特币</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB 可用空间</numerusform></translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>表格</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>未知...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>最后的区块时间</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>计算中...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>估计的同步剩余时间</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation>打开比特币: URI</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI: </translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>默认钱包</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>打开钱包</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation>正在打开钱包&lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;主要</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>登录系统后自动开始 %1。</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>&amp;数据库缓存的大小</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>脚本 &amp;验证线程的数量</translation>
    </message>
    <message>
        <source>Hide the icon from the system tray.</source>
        <translation>从系统托盘中隐藏图标</translation>
    </message>
    <message>
        <source>&amp;Hide tray icon</source>
        <translation>&amp;隐藏托盘图标</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>打开配置文件</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>重置所有客户端选项为默认</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;重置选项</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;网络</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>钱&amp;包</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>专家</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation>&amp;通过 SOCKS5 代理连接（默认代理）</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>代理 &amp;IP：</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;端口</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;窗口</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>表格</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">关闭</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>总计</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely...</source>
        <translation type="unfinished">%1 没有安全退出...</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>转账</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>错误地将 URI 编码成二维码</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;消息</translation>
    </message>
    <message>
        <source>Blocksdir</source>
        <translation>区块目录</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">网络</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">钱包： </translation>
    </message>
    <message>
        <source>Node window</source>
        <translation>结点窗口</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>最后的区块时间</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1 &amp;小时</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1 &amp;周</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1 &amp;年</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;断开连接</translation>
    </message>
    <message>
        <source>1 d&amp;ay</source>
        <translation type="unfinished">1 &amp;天</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>禁用网络活动</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">未知</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;总计：</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;标签：</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;消息：</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;复制标签</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;复制金额</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>不能解锁钱包</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">地址:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>总计：</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">标签:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">消息：</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>钱包：</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>消息</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>数量：</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>字节：</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>总计：</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>手续费：</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>扣除费用后：</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>变化：</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>手续费：</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>Warning: Fee estimation is currently not possible.</source>
        <translation>警告:目前无法估算费用。</translation>
    </message>
    <message>
        <source>Specify a custom fee per kB (1,000 bytes) of the transaction's virtual size.

Note:  Since the fee is calculated on a per-byte basis, a fee of "100 satoshis per kB" for a transaction size of 500 bytes (half of 1 kB) would ultimately yield a fee of only 50 satoshis.</source>
        <translation>指定交易虚拟大小的每kB(1,000字节)的自定义费用。
注意:由于费用是按字节计算的，对于大小为500字节(1 kB的一半)的交易，“每kB 100 satoshis”的费用最终只会产生50 satoshis的费用。</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>一次发送到多个接收</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>粉尘：</translation>
    </message>
    <message>
        <source>When there is less transaction volume than space in the blocks, miners as well as relaying nodes may enforce a minimum fee. Paying only this minimum fee is just fine, but be aware that this can result in a never confirming transaction once there is more demand for bitcoin transactions than the network can process.</source>
        <translation>当交易量小于块的空间时，矿工和中继节点可以强制执行最低费用。只付最低费用就可以了，但注意，一旦比特币交易的需求超出网络的处理能力，就可能导致交易无法确认。</translation>
    </message>
    <message>
        <source>A too low fee might result in a never confirming transaction (read the tooltip)</source>
        <translation>太低的费用可能导致永远无法确认交易(阅读工具提示)</translation>
    </message>
    <message>
        <source>Confirmation time target:</source>
        <translation>目标确认时间：</translation>
    </message>
    <message>
        <source>With Replace-By-Fee (BIP-125) you can increase a transaction's fee after it is sent. Without this, a higher fee may be recommended to compensate for increased transaction delay risk.</source>
        <translation>通过 Replace-By-Fee (BIP-125) 您可以在交易发送后增加交易费用。没有这个，可能会建议收取更高的费用，以补偿交易延迟风险的增加。</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;发送</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>复制数量</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>复制金额</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>复制费用</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>复制扣除费用</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>复制字节</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>复制改变</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>确定发送么？</translation>
    </message>
    <message>
        <source>You can increase the fee later (signals Replace-By-Fee, BIP-125).</source>
        <translation>稍后您可以增加费用( 信号 Replace-By-Fee，BIP-125）。</translation>
    </message>
    <message>
        <source>Please, review your transaction.</source>
        <translation>请检查您的交易。</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>手续费</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">发送</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>收款人地址无效，请再次确认。</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>支付的总额必须大于0。</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>总额超过你的余额。</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>当包含%1交易费用时，总额超过你的余额。</translation>
    </message>
    <message>
        <source>Duplicate address found: addresses should only be used once each.</source>
        <translation>发现重复地址：每个地址只能使用一次。</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>交易创建失败!</translation>
    </message>
    <message>
        <source>A fee higher than %1 is considered an absurdly high fee.</source>
        <translation>高于%1的手续费被认为非常高的手续费。</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>支付请求已过期。</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation><numerusform>估计在%n块内确认。</numerusform></translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>警告：比特币地址无效</translation>
    </message>
    <message>
        <source>The address you selected for change is not part of this wallet. Any or all funds in your wallet may be sent to this address. Are you sure?</source>
        <translation>您选择更改的地址不在此钱包中。钱包里的所有资金都可以发送到这个地址。你确定吗?</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;总计：</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;标签：</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>选择以前使用的地址</translation>
    </message>
    <message>
        <source>The Bitcoin address to send the payment to</source>
        <translation>支付到的比特币地址</translation>
    </message>
    <message>
        <source>The fee will be deducted from the amount being sent. The recipient will receive less bitcoins than you enter in the amount field. If multiple recipients are selected, the fee is split equally.</source>
        <translation>手续费将从发出的总额中扣除。接受者收到的比特币将少于你输入的金额字段。如果选择了多个接受者，手续费将平均分配。</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">消息：</translation>
    </message>
    <message>
        <source>This is an unauthenticated payment request.</source>
        <translation>这是一个未经身份验证的付款请求。</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation>输入此地址的标签，将其添加到使用的地址列表中</translation>
    </message>
    <message>
        <source>A message that was attached to the bitcoin: URI which will be stored with the transaction for your reference. Note: This message will not be sent over the Bitcoin network.</source>
        <translation>附在比特币上的消息:URI将与交易一起存储，供参考。注意：此信息不会通过比特币网络发送。</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Choose previously used address</source>
        <translation>选择以前使用的地址</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;验证消息</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">&amp;验证消息</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>手续费</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>消息</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>转账</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>总计</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(没有标签)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;复制标签</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;复制金额</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;复制交易 ID</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;编辑标签</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔的文件 (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>关闭钱包</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>创建一个新的钱包</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>默认钱包</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;导出</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>将当前选项卡中的数据导出到文件</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">备份钱包</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>所有端口均监听失败。如果这是预料之中的，使用 -listen=0 。</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>正在载入地址...</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>超额转账</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>余额不足</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>正在载入钱包...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>再次扫描...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>载入完成</translation>
    </message>
</context>
</TS>